@@ -40,6 +40,9 @@ pub enum SyntaxError {
 
     InvalidSuperCall,
     InvalidSuper,
+    InvalidSuperPrivateName,
+
+    InvalidImport,
 
     ArrowNotAllowed,
     ExportNotAllowed,
@@ -229,6 +232,7 @@ pub enum SyntaxError {
     TS2703,
     TS4112,
     TSTypeAnnotationAfterAssign,
+    TsNonNullAssertionNotAllowed(JsWord),
 }
 
 impl SyntaxError {
@@ -444,6 +448,10 @@ impl SyntaxError {
             SyntaxError::DeclNotAllowed => "Declaration is now allowed".into(),
             SyntaxError::InvalidSuperCall => "Invalid `super()`".into(),
             SyntaxError::InvalidSuper => "Invalid access to super".into(),
+            SyntaxError::InvalidSuperPrivateName => {
+                "Index super with private name is not allowed".into()
+            }
+            SyntaxError::InvalidImport => "Import is not allowed here".into(),
             SyntaxError::ArrowNotAllowed => "An arrow function is not allowed here".into(),
             SyntaxError::ExportNotAllowed => "`export` is not allowed here".into(),
             SyntaxError::GetterSetterCannotBeReadonly => {
@@ -561,6 +569,11 @@ impl SyntaxError {
             SyntaxError::TSTypeAnnotationAfterAssign => {
                 "Type annotations must come before default assignments".into()
             }
+            SyntaxError::TsNonNullAssertionNotAllowed(word) => format!(
+                "Typescript non-null assertion operator is not allowed with '{}'",
+                word
+            )
+            .into(),
             SyntaxError::SetterParamRequired => "Setter should have exactly one parameter".into(),
         }
     }
