@@ -425,7 +425,7 @@ impl<'a, I: Tokens> Parser<I> {
                 let name = self.parse_ident_name()?;
                 export_ns = Some(ExportSpecifier::Namespace(ExportNamespaceSpecifier {
                     span: span!(self, ns_export_specifier_start),
-                    name,
+                    name: ModuleExportName::Ident(name),
                 }));
             }
         }
